==> payroll_ver_3.2.1.zip: payroll3/pub/system/js/leaveReasonCard.js <==
/*
 * MosP - Mind Open Source Project         http://www.mosp.jp/
 * Copyright (C) 1987-2009 MIND Co., Ltd.  http://www.e-mind.co.jp/
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
/**
 * ʓǍǉ
 * @param 
 * @return 
 * @throws sO
 */
function onLoadExtra() {
	// ڔwiFݒ
	setFieldsBgColor(ARY_FIELDS_ID    , COLOR_FIELD_NORMAL);
	setFieldsBgColor(ARY_ERR_FIELDS_ID, COLOR_FIELD_ERROR );
	// ڒݒ
	for (i = 0; i < 10; i++) {
		setMaxLength(PRM_TXT_LEAVE_REASON + i, LEN_REASON);
	}
	// tH[JXݒ
	setFocus(PRM_TXT_LEAVE_REASON + 0);
}

/**
 * T[o[ʐM
 * @param 
 * @return 
 * @throws sO
 */
function submitForm(objForm) {
	// ̓`FbN
	if (validate()) {
		// T[o[ʐM(̓G[̏ꍇ)
		doSubmitMessage(objForm, 'S2518', 'QC0001', '');
	}
}

/**
 * ̓`FbN
 * @param 
 * @return `FbN(trueFOKAfalseFNG)
 * @throws sO
 */
function validate() {
	// tB[hwiFݒ
	setFieldsBgColor(ARY_FIELDS_ID, COLOR_FIELD_NORMAL);
	// ̓`FbN
	var aryMessage = new Array();
	checkRequired(PRM_TXT_LEAVE_REASON + 0, NAM_LEAVE_REASON + 1, aryMessage);
	checkRequired(PRM_TXT_LEAVE_REASON + 1, NAM_LEAVE_REASON + 2, aryMessage);
	checkRequired(PRM_TXT_LEAVE_REASON + 2, NAM_LEAVE_REASON + 3, aryMessage);
	checkRequired(PRM_TXT_LEAVE_REASON + 3, NAM_LEAVE_REASON + 4, aryMessage);
	checkRequired(PRM_TXT_LEAVE_REASON + 4, NAM_LEAVE_REASON + 5, aryMessage);
	checkRequired(PRM_TXT_LEAVE_REASON + 5, NAM_LEAVE_REASON + 6, aryMessage);

	if (aryMessage.length == 0) {
		return true;
	} else {
		showMessage(aryMessage);
		return false;
	}
}

==> payroll_ver_3.3.1.zip: payroll3/pub/system/js/leaveReasonCard.js <==
/*
 * MosP - Mind Open Source Project    http://www.mosp.jp/
 * Copyright (C) MIND Co., Ltd.       http://www.e-mind.co.jp/
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
/**
 * ʓǍǉ
 * @param 
 * @return 
 * @throws sO
 */
function onLoadExtra() {
	// ڔwiFݒ
	setFieldsBgColor(ARY_FIELDS_ID    , COLOR_FIELD_NORMAL);
	setFieldsBgColor(ARY_ERR_FIELDS_ID, COLOR_FIELD_ERROR );
	// ڒݒ
	for (i = 0; i < 10; i++) {
		setMaxLength(PRM_TXT_LEAVE_REASON + i, LEN_REASON);
	}
	// tH[JXݒ
	setFocus(PRM_TXT_LEAVE_REASON + 0);
}

/**
 * T[o[ʐM
 * @param 
 * @return 
 * @throws sO
 */
function submitForm(objForm) {
	// ̓`FbN
	if (validate()) {
		// T[o[ʐM(̓G[̏ꍇ)
		doSubmitMessage(objForm, 'S2318', 'QC0001', '');
	}
}

/**
 * ̓`FbN
 * @param 
 * @return `FbN(trueFOKAfalseFNG)
 * @throws sO
 */
function validate() {
	// tB[hwiFݒ
	setFieldsBgColor(ARY_FIELDS_ID, COLOR_FIELD_NORMAL);
	// ̓`FbN
	var aryMessage = new Array();
	checkRequired(PRM_TXT_LEAVE_REASON + 0, "1Ԗڂ" + NAM_LEAVE_REASON, aryMessage);
	checkRequired(PRM_TXT_LEAVE_REASON + 1, "2Ԗڂ" + NAM_LEAVE_REASON, aryMessage);
	checkRequired(PRM_TXT_LEAVE_REASON + 2, "3Ԗڂ" + NAM_LEAVE_REASON, aryMessage);
	checkRequired(PRM_TXT_LEAVE_REASON + 3, "4Ԗڂ" + NAM_LEAVE_REASON, aryMessage);
	checkRequired(PRM_TXT_LEAVE_REASON + 4, "5Ԗڂ" + NAM_LEAVE_REASON, aryMessage);
	checkRequired(PRM_TXT_LEAVE_REASON + 5, "6Ԗڂ" + NAM_LEAVE_REASON, aryMessage);

	if (aryMessage.length == 0) {
		return true;
	} else {
		showMessage(aryMessage);
		return false;
	}
}
